@@ -11,7 +11,7 @@ class Provider(BaseProvider):
 
     def name(self):
         """
-        :example 'Jhon Doe'
+        :example 'John Doe'
         """
         pattern = self.random_element(self.formats)
         return self.generator.parse(pattern)
